package dyliss.biopax.app.test;
 

import org.slf4j.LoggerFactory;

import ch.qos.logback.classic.Level;
import ch.qos.logback.classic.Logger;
import dyliss.biopax.app.Pax2GraphML;

public class TestCommandLine {
public static void main(String[] args) throws Exception {
     String d="/home/fmoreews/Documents/keyreg/publi/revision2/";
	 
     //String  biopax_file=d+"subgraph.owl";
     String  biopax_file=d+"PathwayCommons12.ctd.BIOPAX.owl";
   //  String  biopax_file=d+"G6P.owl";
   //  String  biopax_file=d+"PathwayCommons12.pid.BIOPAX.owl";
	// String graphml_file=d+"subgraph_OUT.graphml";
     String graphml_file=d+"ctd.graphml";
	// String  template=d+"graphml.vm";
	 String  template=d+"graphml_l.vm";
	 String  blackListOpt="";
	
	 ch.qos.logback.classic.Logger logger = 
			  (ch.qos.logback.classic.Logger)LoggerFactory.getLogger("dyliss");
		logger.setLevel(Level.TRACE);

	 logger.info("Hi there!");
			Logger rootLogger = 
 					  (ch.qos.logback.classic.Logger)LoggerFactory.getLogger(
 							  org.slf4j.Logger.ROOT_LOGGER_NAME);
  
			     logger.debug("This message is logged because DEBUG == DEBUG.");
					
					//rootLogger.setLevel(Level.TRACE);
					logger.debug("This message is logged because DEBUG == DEBUG.");

			
			
	String[] margs= new String[]{
			"-i",biopax_file,"-o",
			graphml_file,"-t",
			template,"-c","2",
			blackListOpt
			};
    Pax2GraphML.main(margs);
    


}
}
